@@ -31,7 +31,7 @@ where
     /// Finish writing.
     pub fn finish(mut self) -> Result<(), W::Error> {
         if !self.buf.is_empty() {
-            self.writer.write_bytes(self.buf.as_bytes())?;
+            self.writer.write_bytes(self.buf.as_slice())?;
         }
 
         Ok(())
@@ -43,11 +43,17 @@ where
     W: Writer,
 {
     type Error = W::Error;
+    type Mut<'this> = &'this mut Self where Self: 'this;
+
+    #[inline]
+    fn borrow_mut(&mut self) -> Self::Mut<'_> {
+        self
+    }
 
     #[inline]
     fn write_bytes(&mut self, bytes: &[u8]) -> Result<(), Self::Error> {
         if self.buf.remaining() < bytes.len() {
-            self.writer.write_bytes(self.buf.as_bytes())?;
+            self.writer.write_bytes(self.buf.as_slice())?;
             self.buf.clear();
         }
 
